/// <reference types="validator" />
import * as Router from 'koa-router';
export declare function params(options: ParamsOptions): Router.IMiddleware;
export interface ParamsContext {
    errors?: ParamError[];
}
export interface ParamsOptions {
    [key: string]: Validator | Validator[];
}
export declare type Validator = (ctx: Router.IRouterContext, path: string, val: any) => boolean;
export interface ParamError {
    path: string;
    value: any;
    failed: string;
}
export { required, isAscii, isBase64, isBoolean, isCreditCard, isDataURI, isEmpty, isFullWidth, isHalfWidth, isHexColor, isHexadecimal, isISIN, isISO8601, isISO31661Alpha2, isISRC, isJSON, isLatLong, isLowercase, isMACAddress, isMD5, isMimeType, isMongoId, isMultibyte, isNumeric, isPort, isSurrogatePair, isUppercase, isVariableWidth, };
declare const required: Validator;
export declare function contains(seed: string): Validator;
export declare function equals(comparison: string): Validator;
export declare function isAfter(date?: string): Validator;
export declare function isAlpha(locale?: ValidatorJS.AlphaLocale): Validator;
export declare function isAlphanumeric(locale?: ValidatorJS.AlphaLocale): Validator;
declare const isAscii: Validator;
declare const isBase64: Validator;
export declare function isBefore(date?: string): Validator;
declare const isBoolean: Validator;
export declare function isByteLength(min: number, max?: number): Validator;
export declare function isByteLength(options: ValidatorJS.IsByteLengthOptions): Validator;
declare const isCreditCard: Validator;
export declare function isCurrency(options?: ValidatorJS.IsCurrencyOptions): Validator;
declare const isDataURI: Validator;
export declare function isDecimal(options?: ValidatorJS.IsDecimalOptions): Validator;
export declare function isDivisibleBy(number: number): Validator;
export declare function isEmail(options?: ValidatorJS.IsEmailOptions): Validator;
declare const isEmpty: Validator;
export declare function isEnum(enumObject?: object): Validator;
export declare function isFQDN(options?: ValidatorJS.IsFQDNOptions): Validator;
export declare function isFloat(options?: ValidatorJS.IsFloatOptions): Validator;
declare const isFullWidth: Validator;
declare const isHalfWidth: Validator;
export declare function isHash(algorithm: ValidatorJS.HashAlgorithm): Validator;
declare const isHexColor: Validator;
declare const isHexadecimal: Validator;
export declare function isIP(version?: number): Validator;
export declare function isISSN(options?: ValidatorJS.IsISSNOptions): Validator;
declare const isISIN: Validator;
declare const isISO8601: Validator;
declare const isISO31661Alpha2: Validator;
declare const isISRC: Validator;
export declare function isIn(values: any[]): Validator;
export declare function isInt(options?: ValidatorJS.IsIntOptions): Validator;
declare const isJSON: Validator;
declare const isLatLong: Validator;
export declare function isLength(min: number, max?: number): Validator;
export declare function isLength(options: ValidatorJS.IsLengthOptions): Validator;
declare const isLowercase: Validator;
declare const isMACAddress: Validator;
declare const isMD5: Validator;
declare const isMimeType: Validator;
export declare function isMobilePhone(locale: ValidatorJS.MobilePhoneLocale, options?: ValidatorJS.IsMobilePhoneOptions): Validator;
declare const isMongoId: Validator;
declare const isMultibyte: Validator;
declare const isNumeric: Validator;
declare const isPort: Validator;
export declare function isPostalCode(locale: ValidatorJS.PostalCodeLocale): Validator;
declare const isSurrogatePair: Validator;
export declare function isURL(options?: ValidatorJS.IsURLOptions): Validator;
export declare function isUUID(version?: 3 | 4 | 5 | "3" | "4" | "5" | "all"): Validator;
declare const isUppercase: Validator;
declare const isVariableWidth: Validator;
export declare function isWhitelisted(chars: string | string[]): Validator;
export declare function matches(pattern: RegExp | string, modifiers?: string): Validator;
export declare function blacklist(chars: string): Validator;
export declare function escape(ctx: Router.IRouterContext, path: string, val: any): boolean;
export declare function unescape(ctx: Router.IRouterContext, path: string, val: any): boolean;
export declare function ltrim(chars?: string): Validator;
export declare function normalizeEmail(options?: ValidatorJS.NormalizeEmailOptions): Validator;
export declare function rtrim(chars?: string): Validator;
export declare function stripLow(keep_new_lines?: boolean): Validator;
export declare function toBoolean(strict?: boolean): Validator;
export declare function toDate(ctx: Router.IRouterContext, path: string, val: any): boolean;
export declare function toFloat(ctx: Router.IRouterContext, path: string, val: any): boolean;
export declare function toInt(radix?: number): Validator;
export declare function trim(chars?: string): Validator;
export declare function whitelist(chars?: string): Validator;
