"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const _ = require("underscore");
const validator = require("validator");
/* tslint:disable:rule1 no-shadowed-variable */
const dotty = require('dotty');
function params(options) {
    const mappedOptions = _.map(options, (v, key) => {
        const validators = _.flatten([v]);
        if (key.startsWith('!')) {
            validators.push(required);
            key = key.substring(1);
        }
        return { key, validators };
    });
    return async (ctx, next) => {
        ctx.errors = [];
        for (const o of mappedOptions) {
            const value = dotty.get(ctx.request, o.key);
            for (const fn of o.validators) {
                const pass = fn(ctx, o.key, value);
                if (!pass) {
                    ctx.errors.push({
                        path: o.key,
                        value,
                        failed: fn.name,
                    });
                }
            }
        }
        if (!_.isEmpty(ctx.errors)) {
            ctx.body = { errors: ctx.errors };
            ctx.status = 422;
        }
        else {
            await next();
        }
    };
}
exports.params = params;
const required = (ctx, path, val) => val != null;
exports.required = required;
function contains(seed) {
    const contains = (ctx, path, val) => (validator.contains(val, seed));
    return contains;
}
exports.contains = contains;
function equals(comparison) {
    const equals = (ctx, path, val) => (validator.equals(val, comparison));
    return equals;
}
exports.equals = equals;
function isAfter(date) {
    const isAfter = (ctx, path, val) => validator.isAfter(val, date);
    return isAfter;
}
exports.isAfter = isAfter;
function isAlpha(locale) {
    const isAlpha = (ctx, path, val) => (validator.isAlpha(val, locale));
    return isAlpha;
}
exports.isAlpha = isAlpha;
function isAlphanumeric(locale) {
    const isAlphanumeric = (ctx, path, val) => (validator.isAlphanumeric(val, locale));
    return isAlphanumeric;
}
exports.isAlphanumeric = isAlphanumeric;
const isAscii = (ctx, path, val) => (validator.isAscii(val));
exports.isAscii = isAscii;
const isBase64 = (ctx, path, val) => (validator.isBase64(val));
exports.isBase64 = isBase64;
function isBefore(date) {
    const isBefore = (ctx, path, val) => validator.isBefore(val, date);
    return isBefore;
}
exports.isBefore = isBefore;
const isBoolean = (ctx, path, val) => (validator.isBoolean(val));
exports.isBoolean = isBoolean;
function isByteLength(a, b) {
    const isByteLength = (ctx, path, val) => (validator.isByteLength(val, a, b));
    return isByteLength;
}
exports.isByteLength = isByteLength;
const isCreditCard = (ctx, path, val) => (validator.isCreditCard(val));
exports.isCreditCard = isCreditCard;
function isCurrency(options) {
    const isCurrency = (ctx, path, val) => (validator.isCurrency(val, options));
    return isCurrency;
}
exports.isCurrency = isCurrency;
const isDataURI = (ctx, path, val) => (validator.isDataURI(val));
exports.isDataURI = isDataURI;
function isDecimal(options) {
    const isDecimal = (ctx, path, val) => (validator.isDecimal(val, options));
    return isDecimal;
}
exports.isDecimal = isDecimal;
function isDivisibleBy(number) {
    const isDivisibleBy = (ctx, path, val) => (validator.isDivisibleBy(val, number));
    return isDivisibleBy;
}
exports.isDivisibleBy = isDivisibleBy;
function isEmail(options) {
    const isEmail = (ctx, path, val) => (validator.isEmail(val, options));
    return isEmail;
}
exports.isEmail = isEmail;
const isEmpty = (ctx, path, val) => (validator.isEmpty(val));
exports.isEmpty = isEmpty;
function isEnum(enumObject) {
    const values = _.values(enumObject);
    const isEnum = (ctx, path, val) => (_.indexOf(values, val) >= 0);
    return isEnum;
}
exports.isEnum = isEnum;
function isFQDN(options) {
    const isFQDN = (ctx, path, val) => (validator.isFQDN(val, options));
    return isFQDN;
}
exports.isFQDN = isFQDN;
function isFloat(options) {
    const isFloat = (ctx, path, val) => (validator.isFloat(val, options));
    return isFloat;
}
exports.isFloat = isFloat;
const isFullWidth = (ctx, path, val) => (validator.isFullWidth(val));
exports.isFullWidth = isFullWidth;
const isHalfWidth = (ctx, path, val) => (validator.isHalfWidth(val));
exports.isHalfWidth = isHalfWidth;
function isHash(algorithm) {
    const isHash = (ctx, path, val) => (validator.isHash(val, algorithm));
    return isHash;
}
exports.isHash = isHash;
const isHexColor = (ctx, path, val) => (validator.isHexColor(val));
exports.isHexColor = isHexColor;
const isHexadecimal = (ctx, path, val) => (validator.isHexadecimal(val));
exports.isHexadecimal = isHexadecimal;
function isIP(version) {
    const isIP = (ctx, path, val) => (validator.isIP(val, version));
    return isIP;
}
exports.isIP = isIP;
function isISSN(options) {
    const isISSN = (ctx, path, val) => (validator.isISSN(val, options));
    return isISSN;
}
exports.isISSN = isISSN;
const isISIN = (ctx, path, val) => (validator.isISIN(val));
exports.isISIN = isISIN;
const isISO8601 = (ctx, path, val) => (validator.isISO8601(val));
exports.isISO8601 = isISO8601;
const isISO31661Alpha2 = (ctx, path, val) => (validator.isISO31661Alpha2(val));
exports.isISO31661Alpha2 = isISO31661Alpha2;
const isISRC = (ctx, path, val) => (validator.isISRC(val));
exports.isISRC = isISRC;
function isIn(values) {
    const isIn = (ctx, path, val) => (validator.isIn(val, values));
    return isIn;
}
exports.isIn = isIn;
function isInt(options) {
    const isInt = (ctx, path, val) => (validator.isInt(val, options));
    return isInt;
}
exports.isInt = isInt;
const isJSON = (ctx, path, val) => (validator.isJSON(val));
exports.isJSON = isJSON;
const isLatLong = (ctx, path, val) => (validator.isLatLong(val));
exports.isLatLong = isLatLong;
function isLength(a, b) {
    const isLength = (ctx, path, val) => (validator.isLength(val, a, b));
    return isLength;
}
exports.isLength = isLength;
const isLowercase = (ctx, path, val) => (validator.isLowercase(val));
exports.isLowercase = isLowercase;
const isMACAddress = (ctx, path, val) => (validator.isMACAddress(val));
exports.isMACAddress = isMACAddress;
const isMD5 = (ctx, path, val) => (validator.isMD5(val));
exports.isMD5 = isMD5;
const isMimeType = (ctx, path, val) => (validator.isMimeType(val));
exports.isMimeType = isMimeType;
function isMobilePhone(locale, options) {
    const isMobilePhone = (ctx, path, val) => (validator.isMobilePhone(val, locale, options));
    return isMobilePhone;
}
exports.isMobilePhone = isMobilePhone;
const isMongoId = (ctx, path, val) => (validator.isMongoId(val));
exports.isMongoId = isMongoId;
const isMultibyte = (ctx, path, val) => (validator.isMultibyte(val));
exports.isMultibyte = isMultibyte;
const isNumeric = (ctx, path, val) => (validator.isNumeric(val));
exports.isNumeric = isNumeric;
const isPort = (ctx, path, val) => (validator.isPort(val));
exports.isPort = isPort;
function isPostalCode(locale) {
    const isPostalCode = (ctx, path, val) => (validator.isPostalCode(val, locale));
    return isPostalCode;
}
exports.isPostalCode = isPostalCode;
const isSurrogatePair = (ctx, path, val) => (validator.isSurrogatePair(val));
exports.isSurrogatePair = isSurrogatePair;
function isURL(options) {
    const isURL = (ctx, path, val) => (validator.isURL(val, options));
    return isURL;
}
exports.isURL = isURL;
function isUUID(version) {
    const isUUID = (ctx, path, val) => (validator.isUUID(val, version));
    return isUUID;
}
exports.isUUID = isUUID;
const isUppercase = (ctx, path, val) => (validator.isUppercase(val));
exports.isUppercase = isUppercase;
const isVariableWidth = (ctx, path, val) => (validator.isVariableWidth(val));
exports.isVariableWidth = isVariableWidth;
function isWhitelisted(chars) {
    const isWhitelisted = (ctx, path, val) => (validator.isWhitelisted(val, chars));
    return isWhitelisted;
}
exports.isWhitelisted = isWhitelisted;
function matches(pattern, modifiers) {
    const matches = (ctx, path, val) => (validator.matches(val, pattern, modifiers));
    return matches;
}
exports.matches = matches;
// --------------------------- Sanitizers ----------------------------------- //
function blacklist(chars) {
    const blacklist = (ctx, path, val) => {
        dotty.put(ctx.request, path, validator.blacklist(val, chars));
        return true;
    };
    return blacklist;
}
exports.blacklist = blacklist;
function escape(ctx, path, val) {
    dotty.put(ctx.request, path, validator.escape(val));
    return true;
}
exports.escape = escape;
function unescape(ctx, path, val) {
    dotty.put(ctx.request, path, validator.unescape(val));
    return true;
}
exports.unescape = unescape;
function ltrim(chars) {
    const ltrim = (ctx, path, val) => {
        dotty.put(ctx.request, path, validator.ltrim(val, chars));
        return true;
    };
    return ltrim;
}
exports.ltrim = ltrim;
function normalizeEmail(options) {
    const normalizeEmail = (ctx, path, val) => {
        dotty.put(ctx.request, path, validator.normalizeEmail(val, options));
        return true;
    };
    return normalizeEmail;
}
exports.normalizeEmail = normalizeEmail;
function rtrim(chars) {
    const rtrim = (ctx, path, val) => {
        dotty.put(ctx.request, path, validator.rtrim(val, chars));
        return true;
    };
    return rtrim;
}
exports.rtrim = rtrim;
function stripLow(keep_new_lines) {
    const stripLow = (ctx, path, val) => {
        dotty.put(ctx.request, path, validator.stripLow(val, keep_new_lines));
        return true;
    };
    return stripLow;
}
exports.stripLow = stripLow;
function toBoolean(strict) {
    const toBoolean = (ctx, path, val) => {
        dotty.put(ctx.request, path, validator.toBoolean(val, strict));
        return true;
    };
    return toBoolean;
}
exports.toBoolean = toBoolean;
function toDate(ctx, path, val) {
    dotty.put(ctx.request, path, validator.toDate(val));
    return true;
}
exports.toDate = toDate;
function toFloat(ctx, path, val) {
    dotty.put(ctx.request, path, validator.toFloat(val));
    return true;
}
exports.toFloat = toFloat;
function toInt(radix) {
    const toInt = (ctx, path, val) => {
        dotty.put(ctx.request, path, validator.toInt(val, radix));
        return true;
    };
    return toInt;
}
exports.toInt = toInt;
function trim(chars) {
    const trim = (ctx, path, val) => {
        dotty.put(ctx.request, path, validator.trim(val, chars));
        return true;
    };
    return trim;
}
exports.trim = trim;
function whitelist(chars) {
    const whitelist = (ctx, path, val) => {
        dotty.put(ctx.request, path, validator.whitelist(val, chars));
        return true;
    };
    return whitelist;
}
exports.whitelist = whitelist;

//# sourceMappingURL=validators.js.map
